from pyark import cva_client
import logging


class PedigreesClient(cva_client.CvaClient):

    _BASE_ENDPOINT = "pedigrees"

    def __init__(self, url_base, token):
        cva_client.CvaClient.__init__(self, url_base, token=token)

    def get_pedigree(self, identifier, version, as_data_frame=False):
        results, _ = self._get("{endpoint}/{identifier}/{version}".format(
            endpoint=self._BASE_ENDPOINT, identifier=identifier, version=version))
        if not results:
            logging.warning("No pedigree found with id-version {}-{}".format(identifier, version))
            return None
        assert len(results) == 1, "Unexpected number of pedigrees returned when searching by identifier"
        return self._render_single_result(results, as_data_frame=as_data_frame)



from pyark import cva_client
from protocols.protocol_7_2.cva import EvidenceEntryAndVariants


class EvidencesClient(cva_client.CvaClient):

    _BASE_ENDPOINT = "evidences"

    def __init__(self, url_base, token):
        cva_client.CvaClient.__init__(self, url_base, token=token)

    def get_evidences(self, source, max=None, **params):
        url = "{endpoint}/sources/{source}".format(endpoint=self._BASE_ENDPOINT, source=source)
        results = self._paginate(endpoint=url, max=max, **params)
        for r in results:
            yield EvidenceEntryAndVariants.fromJsonDict(r)

    def post_evidences(self, evidence, **params):
        """
        :type evidence: EvidenceEntryAndVariants
        :type params: dict
        :rtype: dict
        """
        return self._post(self._BASE_ENDPOINT, evidence.toJsonDict(), params)



import os
from distutils.core import setup
from setuptools import find_packages
import pyark


test_deps = ['mock']

# read the contents of your README file
this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='clinical-variant-ark',
    version=pyark.VERSION,
    description='A Python client for the Clinical Variant Ark',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    scripts=[],
    url='https://github.com/genomicsengland/pyark',
    download_url="https://github.com/genomicsengland/pyark/archive/v{}.tar.gz".format(pyark.VERSION),
    license='Apache',
    author=['Pablo Riesgo Ferreiro', 'Kevin Savage', 'William Bellamy'],
    author_email='pablo.riesgo-ferreiro@genomicsengland.co.uk',
    install_requires=[
        'requests',
        'furl==1.0.1',
        'gelreportmodels==7.2.10',
        'enum34',
        'pandas',
        'mock',
        'future',
        'pytest'
    ],
    tests_require=test_deps,
    extras_require={'test': test_deps},
    keywords=['CVA', 'pyark', 'clinical variant ark', 'Genomics England'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
      ]
)
